@@ -88,7 +88,7 @@ LibmysqlDynamicProxy::LibmysqlDynamicProxy(const SQLString & dir2look, const SQL
 /* {{{ LibmysqlDynamicProxy::~LibmysqlDynamicProxy() */
 LibmysqlDynamicProxy::~LibmysqlDynamicProxy()
 {
-    ptr2mysql_library_end endProc = symbol_safe_cast<ptr2mysql_library_end>(GetProcAddr("mysql_server_end"));
+  static ptr2mysql_library_end endProc = symbol_safe_cast<ptr2mysql_library_end>(GetProcAddr("mysql_server_end"));
 
   if (endProc != NULL) {
     (*endProc)();
@@ -101,7 +101,7 @@ LibmysqlDynamicProxy::~LibmysqlDynamicProxy()
 void
 LibmysqlDynamicProxy::init_loader()
 {
-  ptr2mysql_library_init initProc = symbol_safe_cast<ptr2mysql_library_init>(GetProcAddr("mysql_server_init"));
+  static ptr2mysql_library_init initProc = symbol_safe_cast<ptr2mysql_library_init>(GetProcAddr("mysql_server_init"));
 
   if (initProc != NULL) {
     (*initProc)(0, NULL, NULL);
@@ -119,7 +119,7 @@ LibmysqlDynamicProxy::init_loader()
 my_ulonglong
 LibmysqlDynamicProxy::affected_rows(MYSQL * mysql)
 {
-  ptr2mysql_affected_rows ptr2_affected_rows = symbol_safe_cast<ptr2mysql_affected_rows>(GetProcAddr("mysql_affected_rows"));
+  static ptr2mysql_affected_rows ptr2_affected_rows = symbol_safe_cast<ptr2mysql_affected_rows>(GetProcAddr("mysql_affected_rows"));
 
   return (*ptr2_affected_rows)(mysql);
 }
@@ -130,7 +130,7 @@ LibmysqlDynamicProxy::affected_rows(MYSQL * mysql)
 my_bool
 LibmysqlDynamicProxy::autocommit(MYSQL * mysql, my_bool mode)
 {
-  ptr2mysql_autocommit ptr2_autocommit = symbol_safe_cast<ptr2mysql_autocommit>(GetProcAddr("mysql_autocommit"));
+  static ptr2mysql_autocommit ptr2_autocommit = symbol_safe_cast<ptr2mysql_autocommit>(GetProcAddr("mysql_autocommit"));
 
   return (*ptr2_autocommit)(mysql, mode);
 }
@@ -141,7 +141,7 @@ LibmysqlDynamicProxy::autocommit(MYSQL * mysql, my_bool mode)
 void
 LibmysqlDynamicProxy::close(MYSQL * mysql)
 {
-    ptr2mysql_close ptr2_close = symbol_safe_cast<ptr2mysql_close>(GetProcAddr("mysql_close"));
+  static ptr2mysql_close ptr2_close = symbol_safe_cast<ptr2mysql_close>(GetProcAddr("mysql_close"));
 
   return (*ptr2_close)(mysql);
 }
@@ -152,7 +152,7 @@ LibmysqlDynamicProxy::close(MYSQL * mysql)
 my_bool
 LibmysqlDynamicProxy::commit(MYSQL * mysql)
 {
-  ptr2mysql_commit ptr2_commit = symbol_safe_cast<ptr2mysql_commit>(GetProcAddr("mysql_commit"));
+  static ptr2mysql_commit ptr2_commit = symbol_safe_cast<ptr2mysql_commit>(GetProcAddr("mysql_commit"));
 
   return (*ptr2_commit)(mysql);
 }
@@ -163,7 +163,7 @@ LibmysqlDynamicProxy::commit(MYSQL * mysql)
 void
 LibmysqlDynamicProxy::data_seek(MYSQL_RES * result, my_ulonglong offset)
 {
-  ptr2mysql_data_seek ptr2_data_seek = symbol_safe_cast<ptr2mysql_data_seek>(GetProcAddr("mysql_data_seek"));
+  static ptr2mysql_data_seek ptr2_data_seek = symbol_safe_cast<ptr2mysql_data_seek>(GetProcAddr("mysql_data_seek"));
 
   return (*ptr2_data_seek)(result, offset);
 }
@@ -174,7 +174,7 @@ LibmysqlDynamicProxy::data_seek(MYSQL_RES * result, my_ulonglong offset)
 void
 LibmysqlDynamicProxy::debug(const char * debug)
 {
-  ptr2mysql_debug ptr2_debug = symbol_safe_cast<ptr2mysql_debug>(GetProcAddr("mysql_debug"));
+  static ptr2mysql_debug ptr2_debug = symbol_safe_cast<ptr2mysql_debug>(GetProcAddr("mysql_debug"));
 
   return (*ptr2_debug)(debug);
 }
@@ -185,7 +185,7 @@ LibmysqlDynamicProxy::debug(const char * debug)
 unsigned int
 LibmysqlDynamicProxy::mysql_errno(MYSQL * mysql)
 {
-  ptr2mysql_errno ptr2_errno = symbol_safe_cast<ptr2mysql_errno>(GetProcAddr("mysql_errno"));
+  static ptr2mysql_errno ptr2_errno = symbol_safe_cast<ptr2mysql_errno>(GetProcAddr("mysql_errno"));
 
   return (*ptr2_errno)(mysql);
 }
@@ -196,7 +196,7 @@ LibmysqlDynamicProxy::mysql_errno(MYSQL * mysql)
 const char *
 LibmysqlDynamicProxy::error(MYSQL * mysql)
 {
-  ptr2mysql_error ptr2_error = symbol_safe_cast<ptr2mysql_error>(GetProcAddr("mysql_error"));
+  static ptr2mysql_error ptr2_error = symbol_safe_cast<ptr2mysql_error>(GetProcAddr("mysql_error"));
 
   return (*ptr2_error)(mysql);
 }
@@ -207,7 +207,7 @@ LibmysqlDynamicProxy::error(MYSQL * mysql)
 MYSQL_FIELD *
 LibmysqlDynamicProxy::fetch_field(MYSQL_RES * result)
 {
-  ptr2mysql_fetch_field ptr2_fetch_field = symbol_safe_cast<ptr2mysql_fetch_field>(GetProcAddr("mysql_fetch_field"));
+  static ptr2mysql_fetch_field ptr2_fetch_field = symbol_safe_cast<ptr2mysql_fetch_field>(GetProcAddr("mysql_fetch_field"));
 
   return (*ptr2_fetch_field)(result);
 }
@@ -218,7 +218,7 @@ LibmysqlDynamicProxy::fetch_field(MYSQL_RES * result)
 MYSQL_FIELD *
 LibmysqlDynamicProxy::fetch_field_direct(MYSQL_RES * result, unsigned int fieldnr)
 {
-  ptr2mysql_fetch_field_direct ptr2fetchFieldDirect=
+  static ptr2mysql_fetch_field_direct ptr2fetchFieldDirect=
         symbol_safe_cast<ptr2mysql_fetch_field_direct>(GetProcAddr("mysql_fetch_field_direct"));
 
   return (*ptr2fetchFieldDirect)(result, fieldnr);
@@ -230,7 +230,7 @@ LibmysqlDynamicProxy::fetch_field_direct(MYSQL_RES * result, unsigned int fieldn
 unsigned long *
 LibmysqlDynamicProxy::fetch_lengths(MYSQL_RES * result)
 {
-  ptr2mysql_fetch_lengths ptr2_fetch_lengths = symbol_safe_cast<ptr2mysql_fetch_lengths>(GetProcAddr("mysql_fetch_lengths"));
+  static ptr2mysql_fetch_lengths ptr2_fetch_lengths = symbol_safe_cast<ptr2mysql_fetch_lengths>(GetProcAddr("mysql_fetch_lengths"));
 
   return (*ptr2_fetch_lengths)(result);
 }
@@ -241,7 +241,7 @@ LibmysqlDynamicProxy::fetch_lengths(MYSQL_RES * result)
 MYSQL_ROW
 LibmysqlDynamicProxy::fetch_row(MYSQL_RES * result)
 {
-  ptr2mysql_fetch_row ptr2_fetch_row = symbol_safe_cast<ptr2mysql_fetch_row>(GetProcAddr("mysql_fetch_row"));
+  static ptr2mysql_fetch_row ptr2_fetch_row = symbol_safe_cast<ptr2mysql_fetch_row>(GetProcAddr("mysql_fetch_row"));
 
   return (*ptr2_fetch_row)(result);
 }
@@ -252,7 +252,7 @@ LibmysqlDynamicProxy::fetch_row(MYSQL_RES * result)
 unsigned int
 LibmysqlDynamicProxy::field_count(MYSQL * mysql)
 {
-  ptr2mysql_field_count ptr2_field_count = symbol_safe_cast<ptr2mysql_field_count>(GetProcAddr("mysql_field_count"));
+  static ptr2mysql_field_count ptr2_field_count = symbol_safe_cast<ptr2mysql_field_count>(GetProcAddr("mysql_field_count"));
 
   return (*ptr2_field_count)(mysql);
 }
@@ -263,7 +263,7 @@ LibmysqlDynamicProxy::field_count(MYSQL * mysql)
 void
 LibmysqlDynamicProxy::free_result(MYSQL_RES * result)
 {
-  ptr2mysql_free_result ptr2_free_result = symbol_safe_cast<ptr2mysql_free_result>(GetProcAddr("mysql_free_result"));
+  static ptr2mysql_free_result ptr2_free_result = symbol_safe_cast<ptr2mysql_free_result>(GetProcAddr("mysql_free_result"));
 
   return (*ptr2_free_result)(result);
 }
@@ -274,7 +274,7 @@ LibmysqlDynamicProxy::free_result(MYSQL_RES * result)
 unsigned long
 LibmysqlDynamicProxy::get_client_version()
 {
-  ptr2mysql_get_client_version ptr2_get_client_version=
+  static ptr2mysql_get_client_version ptr2_get_client_version=
     (ptr2mysql_get_client_version)(GetProcAddr("mysql_get_client_version"));
 
   return (*ptr2_get_client_version)();
@@ -286,7 +286,7 @@ LibmysqlDynamicProxy::get_client_version()
 const char *
 LibmysqlDynamicProxy::get_server_info(MYSQL * mysql)
 {
-  ptr2mysql_get_server_info ptr2_get_server_info = symbol_safe_cast<ptr2mysql_get_server_info>(GetProcAddr("mysql_get_server_info"));
+  static ptr2mysql_get_server_info ptr2_get_server_info = symbol_safe_cast<ptr2mysql_get_server_info>(GetProcAddr("mysql_get_server_info"));
 
   return (*ptr2_get_server_info)(mysql);
 }
@@ -297,7 +297,7 @@ LibmysqlDynamicProxy::get_server_info(MYSQL * mysql)
 unsigned long
 LibmysqlDynamicProxy::get_server_version(MYSQL * mysql)
 {
-  ptr2mysql_get_server_version ptr2_get_server_version = symbol_safe_cast<ptr2mysql_get_server_version>(GetProcAddr("mysql_get_server_version"));
+  static ptr2mysql_get_server_version ptr2_get_server_version = symbol_safe_cast<ptr2mysql_get_server_version>(GetProcAddr("mysql_get_server_version"));
 
   return (*ptr2_get_server_version)(mysql);
 }
@@ -308,7 +308,7 @@ LibmysqlDynamicProxy::get_server_version(MYSQL * mysql)
 void
 LibmysqlDynamicProxy::get_character_set_info(MYSQL * mysql, void *cs)
 {
-  ptr2mysql_get_character_set_info ptr2_get_character_set_info = symbol_safe_cast<ptr2mysql_get_character_set_info>(GetProcAddr("mysql_get_character_set_info"));
+  static ptr2mysql_get_character_set_info ptr2_get_character_set_info = symbol_safe_cast<ptr2mysql_get_character_set_info>(GetProcAddr("mysql_get_character_set_info"));
 
   return (*ptr2_get_character_set_info)(mysql, static_cast<MY_CHARSET_INFO *>(cs));
 }
@@ -319,7 +319,7 @@ LibmysqlDynamicProxy::get_character_set_info(MYSQL * mysql, void *cs)
 const char *
 LibmysqlDynamicProxy::info(MYSQL * mysql)
 {
-  ptr2mysql_info ptr2_info = symbol_safe_cast<ptr2mysql_info>(GetProcAddr("mysql_info"));
+  static ptr2mysql_info ptr2_info = symbol_safe_cast<ptr2mysql_info>(GetProcAddr("mysql_info"));
 
   return (*ptr2_info)(mysql);
 }
@@ -330,7 +330,7 @@ LibmysqlDynamicProxy::info(MYSQL * mysql)
 MYSQL *
 LibmysqlDynamicProxy::init(MYSQL * mysql)
 {
-  ptr2mysql_init ptr2init = symbol_safe_cast<ptr2mysql_init>(GetProcAddr("mysql_init"));
+  static ptr2mysql_init ptr2init = symbol_safe_cast<ptr2mysql_init>(GetProcAddr("mysql_init"));
 
   return (*ptr2init)(mysql);
 }
@@ -341,7 +341,7 @@ LibmysqlDynamicProxy::init(MYSQL * mysql)
 int
 LibmysqlDynamicProxy::library_init(int argc,char **argv,char **groups)
 {
-  ptr2mysql_library_init ptr2_library_init = symbol_safe_cast<ptr2mysql_library_init>(GetProcAddr("mysql_library_init"));
+  static ptr2mysql_library_init ptr2_library_init = symbol_safe_cast<ptr2mysql_library_init>(GetProcAddr("mysql_library_init"));
 
   return (*ptr2_library_init)(argc, argv, groups);
 }
@@ -352,7 +352,7 @@ LibmysqlDynamicProxy::library_init(int argc,char **argv,char **groups)
 void
 LibmysqlDynamicProxy::library_end()
 {
-  ptr2mysql_library_end ptr2_library_end = symbol_safe_cast<ptr2mysql_library_end>(GetProcAddr("mysql_library_end"));
+  static ptr2mysql_library_end ptr2_library_end = symbol_safe_cast<ptr2mysql_library_end>(GetProcAddr("mysql_library_end"));
 
   return (*ptr2_library_end)();
 }
@@ -363,7 +363,7 @@ LibmysqlDynamicProxy::library_end()
 my_bool
 LibmysqlDynamicProxy::more_results(MYSQL * mysql)
 {
-  ptr2mysql_more_results ptr2_more_results = symbol_safe_cast<ptr2mysql_more_results>(GetProcAddr("mysql_more_results"));
+  static ptr2mysql_more_results ptr2_more_results = symbol_safe_cast<ptr2mysql_more_results>(GetProcAddr("mysql_more_results"));
 
   return (*ptr2_more_results)(mysql);
 }
@@ -374,7 +374,7 @@ LibmysqlDynamicProxy::more_results(MYSQL * mysql)
 int
 LibmysqlDynamicProxy::next_result(MYSQL * mysql)
 {
-  ptr2mysql_next_result ptr2_next_result = symbol_safe_cast<ptr2mysql_next_result>(GetProcAddr("mysql_next_result"));
+  static ptr2mysql_next_result ptr2_next_result = symbol_safe_cast<ptr2mysql_next_result>(GetProcAddr("mysql_next_result"));
 
   return (*ptr2_next_result)(mysql);
 }
@@ -385,7 +385,7 @@ LibmysqlDynamicProxy::next_result(MYSQL * mysql)
 unsigned int
 LibmysqlDynamicProxy::num_fields(MYSQL_RES * result)
 {
-  ptr2mysql_num_fields ptr2_num_fields = symbol_safe_cast<ptr2mysql_num_fields>(GetProcAddr("mysql_num_fields"));
+  static ptr2mysql_num_fields ptr2_num_fields = symbol_safe_cast<ptr2mysql_num_fields>(GetProcAddr("mysql_num_fields"));
 
   return (*ptr2_num_fields)(result);
 }
@@ -396,7 +396,7 @@ LibmysqlDynamicProxy::num_fields(MYSQL_RES * result)
 my_ulonglong
 LibmysqlDynamicProxy::num_rows(MYSQL_RES * result)
 {
-  ptr2mysql_num_rows ptr2_num_rows = symbol_safe_cast<ptr2mysql_num_rows>(GetProcAddr("mysql_num_rows"));
+  static ptr2mysql_num_rows ptr2_num_rows = symbol_safe_cast<ptr2mysql_num_rows>(GetProcAddr("mysql_num_rows"));
 
   return (*ptr2_num_rows)(result);
 }
@@ -407,7 +407,7 @@ LibmysqlDynamicProxy::num_rows(MYSQL_RES * result)
 int
 LibmysqlDynamicProxy::options(MYSQL * mysql, enum mysql_option option, const void *arg)
 {
-  ptr2mysql_options ptr2_options = symbol_safe_cast<ptr2mysql_options>(GetProcAddr("mysql_options"));
+  static ptr2mysql_options ptr2_options = symbol_safe_cast<ptr2mysql_options>(GetProcAddr("mysql_options"));
 
   if ((*ptr2_options)(mysql, option, arg)) {
     throw sql::InvalidArgumentException("Unsupported option provided to mysql_options()");
@@ -422,7 +422,7 @@ LibmysqlDynamicProxy::options(MYSQL * mysql, enum mysql_option option, const voi
 int
 LibmysqlDynamicProxy::options(MYSQL * mysql, enum mysql_option option, const void *arg1, const void *arg2)
 {
-  ptr2mysql_options4 ptr2_options = symbol_safe_cast<ptr2mysql_options4>(GetProcAddr("mysql_options4"));
+  static ptr2mysql_options4 ptr2_options = symbol_safe_cast<ptr2mysql_options4>(GetProcAddr("mysql_options4"));
   if (ptr2_options != NULL) {
     if (((*ptr2_options)(mysql, option, arg1, arg2))) {
       throw sql::InvalidArgumentException("Unsupported option provided to mysql_options4()");
@@ -440,7 +440,7 @@ LibmysqlDynamicProxy::options(MYSQL * mysql, enum mysql_option option, const voi
 int
 LibmysqlDynamicProxy::get_option(MYSQL * mysql, enum mysql_option option, const void *arg)
 {
-  ptr2mysql_get_option ptr2_get_option = symbol_safe_cast<ptr2mysql_options>(GetProcAddr("mysql_get_option"));
+  static ptr2mysql_get_option ptr2_get_option = symbol_safe_cast<ptr2mysql_options>(GetProcAddr("mysql_get_option"));
   if (ptr2_get_option != NULL) {
     if (((*ptr2_get_option)(mysql, option, arg))) {
       throw sql::InvalidArgumentException("Unsupported option provided to mysql_get_option()");
@@ -454,11 +454,70 @@ LibmysqlDynamicProxy::get_option(MYSQL * mysql, enum mysql_option option, const
 /* }}} */
 
 
+/* {{{ LibmysqlDynamicProxy::get_option() */
+st_mysql_client_plugin*
+LibmysqlDynamicProxy::client_find_plugin(MYSQL *mysql, const char *plugin_name, int plugin_type)
+{
+  static ptr2mysql_client_find_plugin ptr2_client_find_plugin = symbol_safe_cast<ptr2mysql_client_find_plugin>(GetProcAddr("mysql_client_find_plugin"));
+  if (ptr2_client_find_plugin != NULL) {
+    st_mysql_client_plugin *plugin = (*ptr2_client_find_plugin)(mysql, plugin_name, plugin_type);
+    if(!plugin)
+    {
+      std::string err("Couldn't load plugin ");
+      err+=plugin_name;
+      throw sql::MethodNotImplementedException(err);
+    }
+    return plugin;
+  } else {
+    throw ::sql::MethodNotImplementedException("::mysql_client_find_plugin()");
+  }
+}
+/* }}} */
+
+
+/* {{{ LibmysqlDynamicProxy::plugin_options() */
+int
+LibmysqlDynamicProxy::plugin_options(st_mysql_client_plugin *plugin, const char *option, const void *value)
+{
+  static ptr2mysql_plugin_options ptr2_plugin_options = symbol_safe_cast<ptr2mysql_plugin_options>(GetProcAddr("mysql_plugin_options"));
+  if (ptr2_plugin_options != NULL) {
+    if (((*ptr2_plugin_options)(plugin, option, value))) {
+      std::string err("Failed to set plugin option");
+      err += " '" + std::string(option) + "'";
+      throw sql::InvalidArgumentException(err);
+    } else {
+      return 0;
+    }
+  } else {
+    throw ::sql::MethodNotImplementedException("::mysql_plugin_options");
+  }
+}
+/* }}} */
+
+
+/* {{{ LibmysqlDynamicProxy::plugin_get_option() */
+int
+LibmysqlDynamicProxy::plugin_get_option(st_mysql_client_plugin *plugin, const char *option, void *value)
+{
+  static ptr2mysql_plugin_get_option ptr2_plugin_get_option = symbol_safe_cast<ptr2mysql_plugin_get_option>(GetProcAddr("mysql_plugin_get_option"));
+  if (ptr2_plugin_get_option != NULL) {
+    if (((*ptr2_plugin_get_option)(plugin, option, value))) {
+      throw sql::InvalidArgumentException("Unsupported option provided to mysql_plugin_get_option()");
+    } else {
+      return 0;
+    }
+  } else {
+    throw ::sql::MethodNotImplementedException("::mysql_plugin_get_option");
+  }
+}
+/* }}} */
+
+
 /* {{{ LibmysqlDynamicProxy::query() */
 int
 LibmysqlDynamicProxy::query(MYSQL * mysql, const char *stmt_str)
 {
-  ptr2mysql_query ptr2_query = symbol_safe_cast<ptr2mysql_query>(GetProcAddr("mysql_query"));
+  static ptr2mysql_query ptr2_query = symbol_safe_cast<ptr2mysql_query>(GetProcAddr("mysql_query"));
 
   return (*ptr2_query)(mysql, stmt_str);
 }
@@ -469,7 +528,7 @@ LibmysqlDynamicProxy::query(MYSQL * mysql, const char *stmt_str)
 int
 LibmysqlDynamicProxy::ping(MYSQL * mysql)
 {
-  ptr2mysql_ping ptr2_ping = symbol_safe_cast<ptr2mysql_ping>(GetProcAddr("mysql_ping"));
+  static ptr2mysql_ping ptr2_ping = symbol_safe_cast<ptr2mysql_ping>(GetProcAddr("mysql_ping"));
 
   return (*ptr2_ping)(mysql);
 }
@@ -487,7 +546,7 @@ LibmysqlDynamicProxy::real_connect(MYSQL * mysql,
                         const char * unix_socket,
                         unsigned long client_flag)
 {
-  ptr2mysql_real_connect ptr2_real_connect=
+  static ptr2mysql_real_connect ptr2_real_connect=
     symbol_safe_cast<ptr2mysql_real_connect>(GetProcAddr("mysql_real_connect"));
 
   return (*ptr2_real_connect)(mysql, host, user, passwd, db, port, unix_socket, client_flag);
@@ -504,7 +563,7 @@ LibmysqlDynamicProxy::real_connect_dns_srv(MYSQL * mysql,
                         const char * db,
                         unsigned long client_flag)
 {
-  ptr2mysql_real_connect_dns_srv ptr2_real_connect_dns_srv=
+  static ptr2mysql_real_connect_dns_srv ptr2_real_connect_dns_srv=
     symbol_safe_cast<ptr2mysql_real_connect_dns_srv>(GetProcAddr("mysql_real_connect_dns_srv"));
 
   return (*ptr2_real_connect_dns_srv)(mysql, host, user, passwd, db, client_flag);
@@ -512,11 +571,24 @@ LibmysqlDynamicProxy::real_connect_dns_srv(MYSQL * mysql,
 /* }}} */
 
 
+/* {{{ LibmysqlDynamicProxy::bind_param() */
+bool
+LibmysqlDynamicProxy::bind_param(MYSQL *mysql, unsigned n_params,
+                                 MYSQL_BIND *binds, const char **names)
+{
+  static ptr2mysql_bind_param ptr2_bind_param=
+    symbol_safe_cast<ptr2mysql_bind_param>(GetProcAddr("mysql_bind_param"));
+
+  return (*ptr2_bind_param)(mysql, n_params, binds, names);
+}
+/* }}} */
+
+
 /* {{{ LibmysqlDynamicProxy::real_escape_string() */
 unsigned long
 LibmysqlDynamicProxy::real_escape_string(MYSQL * mysql, char * to, const char * from, unsigned long length)
 {
-  ptr2mysql_real_escape_string ptr2_realescapestring = symbol_safe_cast<ptr2mysql_real_escape_string>(GetProcAddr("mysql_real_escape_string"));
+  static ptr2mysql_real_escape_string ptr2_realescapestring = symbol_safe_cast<ptr2mysql_real_escape_string>(GetProcAddr("mysql_real_escape_string"));
 
   return (*ptr2_realescapestring)(mysql, to, from, length);
 }
@@ -527,7 +599,7 @@ LibmysqlDynamicProxy::real_escape_string(MYSQL * mysql, char * to, const char *
 int
 LibmysqlDynamicProxy::real_query(MYSQL *mysql,const char *stmt_str, unsigned long len)
 {
-  ptr2mysql_real_query ptr2_real_query = symbol_safe_cast<ptr2mysql_real_query>(GetProcAddr("mysql_real_query"));
+  static ptr2mysql_real_query ptr2_real_query = symbol_safe_cast<ptr2mysql_real_query>(GetProcAddr("mysql_real_query"));
 
   return (*ptr2_real_query)(mysql, stmt_str, len);
 }
@@ -538,7 +610,7 @@ LibmysqlDynamicProxy::real_query(MYSQL *mysql,const char *stmt_str, unsigned lon
 my_bool
 LibmysqlDynamicProxy::rollback(MYSQL * mysql)
 {
-  ptr2mysql_rollback ptr2_rollback = symbol_safe_cast<ptr2mysql_rollback>(GetProcAddr("mysql_rollback"));
+  static ptr2mysql_rollback ptr2_rollback = symbol_safe_cast<ptr2mysql_rollback>(GetProcAddr("mysql_rollback"));
 
   return (*ptr2_rollback)(mysql);
 }
@@ -549,7 +621,7 @@ LibmysqlDynamicProxy::rollback(MYSQL * mysql)
 const char *
 LibmysqlDynamicProxy::sqlstate(MYSQL * mysql)
 {
-  ptr2mysql_sqlstate ptr2_sqlstate = symbol_safe_cast<ptr2mysql_sqlstate>(GetProcAddr("mysql_sqlstate"));
+  static ptr2mysql_sqlstate ptr2_sqlstate = symbol_safe_cast<ptr2mysql_sqlstate>(GetProcAddr("mysql_sqlstate"));
 
   return (*ptr2_sqlstate)(mysql);
 }
@@ -565,7 +637,7 @@ LibmysqlDynamicProxy::ssl_set(MYSQL * mysql,
                       const char * capath,
                       const char * cipher)
 {
-  ptr2mysql_ssl_set ptr2_ssl_set = symbol_safe_cast<ptr2mysql_ssl_set>(GetProcAddr("mysql_ssl_set"));
+  static ptr2mysql_ssl_set ptr2_ssl_set = symbol_safe_cast<ptr2mysql_ssl_set>(GetProcAddr("mysql_ssl_set"));
 
   return (*ptr2_ssl_set)(mysql, key, cert, ca, capath, cipher);
 }
@@ -576,7 +648,7 @@ LibmysqlDynamicProxy::ssl_set(MYSQL * mysql,
 MYSQL_RES *
 LibmysqlDynamicProxy::store_result(MYSQL * mysql)
 {
-  ptr2mysql_store_result ptr2_store_result = symbol_safe_cast<ptr2mysql_store_result>(GetProcAddr("mysql_store_result"));
+  static ptr2mysql_store_result ptr2_store_result = symbol_safe_cast<ptr2mysql_store_result>(GetProcAddr("mysql_store_result"));
 
   return (*ptr2_store_result)(mysql);
 }
@@ -587,7 +659,7 @@ LibmysqlDynamicProxy::store_result(MYSQL * mysql)
 MYSQL_RES *
 LibmysqlDynamicProxy::use_result(MYSQL * mysql)
 {
-  ptr2mysql_use_result ptr2_use_result = symbol_safe_cast<ptr2mysql_use_result>(GetProcAddr("mysql_use_result"));
+  static ptr2mysql_use_result ptr2_use_result = symbol_safe_cast<ptr2mysql_use_result>(GetProcAddr("mysql_use_result"));
 
   return (*ptr2_use_result)(mysql);
 }
@@ -598,7 +670,7 @@ LibmysqlDynamicProxy::use_result(MYSQL * mysql)
 unsigned int
 LibmysqlDynamicProxy::warning_count(MYSQL * mysql)
 {
-  ptr2mysql_warning_count ptr2_warning_count= symbol_safe_cast<ptr2mysql_warning_count>(GetProcAddr("mysql_warning_count"));
+  static ptr2mysql_warning_count ptr2_warning_count= symbol_safe_cast<ptr2mysql_warning_count>(GetProcAddr("mysql_warning_count"));
 
   return (*ptr2_warning_count)(mysql);
 }
@@ -611,7 +683,7 @@ LibmysqlDynamicProxy::warning_count(MYSQL * mysql)
 my_ulonglong
 LibmysqlDynamicProxy::stmt_affected_rows(MYSQL_STMT *stmt)
 {
-  ptr2mysql_stmt_affected_rows ptr2_stmt_affected_rows = symbol_safe_cast<ptr2mysql_stmt_affected_rows>(GetProcAddr("mysql_stmt_affected_rows"));
+  static ptr2mysql_stmt_affected_rows ptr2_stmt_affected_rows = symbol_safe_cast<ptr2mysql_stmt_affected_rows>(GetProcAddr("mysql_stmt_affected_rows"));
 
   return (*ptr2_stmt_affected_rows)(stmt);
 }
@@ -622,7 +694,7 @@ LibmysqlDynamicProxy::stmt_affected_rows(MYSQL_STMT *stmt)
 my_bool
 LibmysqlDynamicProxy::stmt_attr_set(MYSQL_STMT * stmt, enum enum_stmt_attr_type option, const void * arg)
 {
-  ptr2mysql_stmt_attr_set ptr2_stmt_attr_set = symbol_safe_cast<ptr2mysql_stmt_attr_set>(GetProcAddr("mysql_stmt_attr_set"));
+  static ptr2mysql_stmt_attr_set ptr2_stmt_attr_set = symbol_safe_cast<ptr2mysql_stmt_attr_set>(GetProcAddr("mysql_stmt_attr_set"));
 
   return (*ptr2_stmt_attr_set)(stmt, option, arg);
 }
@@ -633,7 +705,7 @@ LibmysqlDynamicProxy::stmt_attr_set(MYSQL_STMT * stmt, enum enum_stmt_attr_type
 my_bool
 LibmysqlDynamicProxy::stmt_bind_param(MYSQL_STMT * stmt, MYSQL_BIND * bind)
 {
-  ptr2mysql_stmt_bind_param ptr2_stmt_bind_param = symbol_safe_cast<ptr2mysql_stmt_bind_param>(GetProcAddr("mysql_stmt_bind_param"));
+  static ptr2mysql_stmt_bind_param ptr2_stmt_bind_param = symbol_safe_cast<ptr2mysql_stmt_bind_param>(GetProcAddr("mysql_stmt_bind_param"));
 
   return (*ptr2_stmt_bind_param)(stmt, bind);
 }
@@ -644,7 +716,7 @@ LibmysqlDynamicProxy::stmt_bind_param(MYSQL_STMT * stmt, MYSQL_BIND * bind)
 my_bool
 LibmysqlDynamicProxy::stmt_bind_result(MYSQL_STMT * stmt, MYSQL_BIND * bind)
 {
-  ptr2mysql_stmt_bind_result ptr2_stmt_bind_result = symbol_safe_cast<ptr2mysql_stmt_bind_result>(GetProcAddr("mysql_stmt_bind_result"));
+  static ptr2mysql_stmt_bind_result ptr2_stmt_bind_result = symbol_safe_cast<ptr2mysql_stmt_bind_result>(GetProcAddr("mysql_stmt_bind_result"));
 
   return (*ptr2_stmt_bind_result)(stmt, bind);
 }
@@ -655,7 +727,7 @@ LibmysqlDynamicProxy::stmt_bind_result(MYSQL_STMT * stmt, MYSQL_BIND * bind)
 my_bool
 LibmysqlDynamicProxy::stmt_close(MYSQL_STMT * stmt)
 {
-  ptr2mysql_stmt_close ptr2_stmt_close = symbol_safe_cast<ptr2mysql_stmt_close>(GetProcAddr("mysql_stmt_close"));
+  static ptr2mysql_stmt_close ptr2_stmt_close = symbol_safe_cast<ptr2mysql_stmt_close>(GetProcAddr("mysql_stmt_close"));
 
   return (*ptr2_stmt_close)(stmt);
 }
@@ -666,7 +738,7 @@ LibmysqlDynamicProxy::stmt_close(MYSQL_STMT * stmt)
 void
 LibmysqlDynamicProxy::stmt_data_seek(MYSQL_STMT * stmt, my_ulonglong row_nr)
 {
-  ptr2mysql_stmt_data_seek ptr2_stmt_data_seek = symbol_safe_cast<ptr2mysql_stmt_data_seek>(GetProcAddr("mysql_stmt_data_seek"));
+  static ptr2mysql_stmt_data_seek ptr2_stmt_data_seek = symbol_safe_cast<ptr2mysql_stmt_data_seek>(GetProcAddr("mysql_stmt_data_seek"));
 
   return (*ptr2_stmt_data_seek)(stmt, row_nr);
 }
@@ -677,7 +749,7 @@ LibmysqlDynamicProxy::stmt_data_seek(MYSQL_STMT * stmt, my_ulonglong row_nr)
 unsigned int
 LibmysqlDynamicProxy::stmt_errno(MYSQL_STMT * stmt)
 {
-  ptr2mysql_stmt_errno ptr2_stmt_errno = symbol_safe_cast<ptr2mysql_stmt_errno>(GetProcAddr("mysql_stmt_errno"));
+  static ptr2mysql_stmt_errno ptr2_stmt_errno = symbol_safe_cast<ptr2mysql_stmt_errno>(GetProcAddr("mysql_stmt_errno"));
 
   return (*ptr2_stmt_errno)(stmt);
 }
@@ -688,7 +760,7 @@ LibmysqlDynamicProxy::stmt_errno(MYSQL_STMT * stmt)
 const char *
 LibmysqlDynamicProxy::stmt_error(MYSQL_STMT * stmt)
 {
-  ptr2mysql_stmt_error ptr2_stmt_error = symbol_safe_cast<ptr2mysql_stmt_error>(GetProcAddr("mysql_stmt_error"));
+  static ptr2mysql_stmt_error ptr2_stmt_error = symbol_safe_cast<ptr2mysql_stmt_error>(GetProcAddr("mysql_stmt_error"));
 
   return (*ptr2_stmt_error)(stmt);
 }
@@ -699,7 +771,7 @@ LibmysqlDynamicProxy::stmt_error(MYSQL_STMT * stmt)
 int
 LibmysqlDynamicProxy::stmt_execute(MYSQL_STMT * stmt)
 {
-  ptr2mysql_stmt_execute ptr2_stmt_execute = symbol_safe_cast<ptr2mysql_stmt_execute>(GetProcAddr("mysql_stmt_execute"));
+  static ptr2mysql_stmt_execute ptr2_stmt_execute = symbol_safe_cast<ptr2mysql_stmt_execute>(GetProcAddr("mysql_stmt_execute"));
 
   return (*ptr2_stmt_execute)(stmt);
 }
@@ -710,7 +782,7 @@ LibmysqlDynamicProxy::stmt_execute(MYSQL_STMT * stmt)
 int
 LibmysqlDynamicProxy::stmt_fetch(MYSQL_STMT * stmt)
 {
-  ptr2mysql_stmt_fetch ptr2_stmt_fetch = symbol_safe_cast<ptr2mysql_stmt_fetch>(GetProcAddr("mysql_stmt_fetch"));
+  static ptr2mysql_stmt_fetch ptr2_stmt_fetch = symbol_safe_cast<ptr2mysql_stmt_fetch>(GetProcAddr("mysql_stmt_fetch"));
 
   return (*ptr2_stmt_fetch)(stmt);
 }
@@ -721,7 +793,7 @@ LibmysqlDynamicProxy::stmt_fetch(MYSQL_STMT * stmt)
 unsigned int
 LibmysqlDynamicProxy::stmt_field_count(MYSQL_STMT * stmt)
 {
-  ptr2mysql_stmt_field_count ptr2_stmt_field_count = symbol_safe_cast<ptr2mysql_stmt_field_count>(GetProcAddr("mysql_stmt_field_count"));
+  static ptr2mysql_stmt_field_count ptr2_stmt_field_count = symbol_safe_cast<ptr2mysql_stmt_field_count>(GetProcAddr("mysql_stmt_field_count"));
 
   return (*ptr2_stmt_field_count)(stmt);
 }
@@ -732,7 +804,7 @@ LibmysqlDynamicProxy::stmt_field_count(MYSQL_STMT * stmt)
 MYSQL_STMT *
 LibmysqlDynamicProxy::stmt_init(MYSQL * mysql)
 {
-  ptr2mysql_stmt_init ptr2_stmt_init = symbol_safe_cast<ptr2mysql_stmt_init>(GetProcAddr("mysql_stmt_init"));
+  static ptr2mysql_stmt_init ptr2_stmt_init = symbol_safe_cast<ptr2mysql_stmt_init>(GetProcAddr("mysql_stmt_init"));
 
   return (*ptr2_stmt_init)(mysql);
 }
@@ -743,7 +815,7 @@ LibmysqlDynamicProxy::stmt_init(MYSQL * mysql)
 my_ulonglong
 LibmysqlDynamicProxy::stmt_num_rows(MYSQL_STMT * stmt)
 {
-  ptr2mysql_stmt_num_rows ptr2_stmt_num_rows = symbol_safe_cast<ptr2mysql_stmt_num_rows>(GetProcAddr("mysql_stmt_num_rows"));
+  static ptr2mysql_stmt_num_rows ptr2_stmt_num_rows = symbol_safe_cast<ptr2mysql_stmt_num_rows>(GetProcAddr("mysql_stmt_num_rows"));
 
   return (*ptr2_stmt_num_rows)(stmt);
 }
@@ -754,7 +826,7 @@ LibmysqlDynamicProxy::stmt_num_rows(MYSQL_STMT * stmt)
 unsigned long
 LibmysqlDynamicProxy::stmt_param_count(MYSQL_STMT * stmt)
 {
-  ptr2mysql_stmt_param_count ptr2_stmt_param_count = symbol_safe_cast<ptr2mysql_stmt_param_count>(GetProcAddr("mysql_stmt_param_count"));
+  static ptr2mysql_stmt_param_count ptr2_stmt_param_count = symbol_safe_cast<ptr2mysql_stmt_param_count>(GetProcAddr("mysql_stmt_param_count"));
 
   return (*ptr2_stmt_param_count)(stmt);
 }
@@ -765,7 +837,7 @@ LibmysqlDynamicProxy::stmt_param_count(MYSQL_STMT * stmt)
 int
 LibmysqlDynamicProxy::stmt_prepare(MYSQL_STMT * stmt, const char * stmt_str, unsigned long len)
 {
-  ptr2mysql_stmt_prepare ptr2_stmt_prepare = symbol_safe_cast<ptr2mysql_stmt_prepare>(GetProcAddr("mysql_stmt_prepare"));
+  static ptr2mysql_stmt_prepare ptr2_stmt_prepare = symbol_safe_cast<ptr2mysql_stmt_prepare>(GetProcAddr("mysql_stmt_prepare"));
 
   return (*ptr2_stmt_prepare)(stmt, stmt_str, len);
 }
@@ -776,7 +848,7 @@ LibmysqlDynamicProxy::stmt_prepare(MYSQL_STMT * stmt, const char * stmt_str, uns
 MYSQL_RES *
 LibmysqlDynamicProxy::stmt_result_metadata(MYSQL_STMT * stmt)
 {
-  ptr2mysql_stmt_result_metadata ptr2_stmt_result_metadata = symbol_safe_cast<ptr2mysql_stmt_result_metadata>(GetProcAddr("mysql_stmt_result_metadata"));
+  static ptr2mysql_stmt_result_metadata ptr2_stmt_result_metadata = symbol_safe_cast<ptr2mysql_stmt_result_metadata>(GetProcAddr("mysql_stmt_result_metadata"));
 
   return (*ptr2_stmt_result_metadata)(stmt);
 }
@@ -787,7 +859,7 @@ LibmysqlDynamicProxy::stmt_result_metadata(MYSQL_STMT * stmt)
 my_bool
 LibmysqlDynamicProxy::stmt_send_long_data(MYSQL_STMT * stmt, unsigned int par_number, const char * data, unsigned long len)
 {
-  ptr2mysql_stmt_send_long_data ptr2_stmt_send_long_data = symbol_safe_cast<ptr2mysql_stmt_send_long_data>(GetProcAddr("mysql_stmt_send_long_data"));
+  static ptr2mysql_stmt_send_long_data ptr2_stmt_send_long_data = symbol_safe_cast<ptr2mysql_stmt_send_long_data>(GetProcAddr("mysql_stmt_send_long_data"));
 
   return (*ptr2_stmt_send_long_data)(stmt, par_number, data, len);
 }
@@ -798,7 +870,7 @@ LibmysqlDynamicProxy::stmt_send_long_data(MYSQL_STMT * stmt, unsigned int par_nu
 const char *
 LibmysqlDynamicProxy::stmt_sqlstate(MYSQL_STMT * stmt)
 {
-  ptr2mysql_stmt_sqlstate ptr2_stmt_sqlstate = symbol_safe_cast<ptr2mysql_stmt_sqlstate>(GetProcAddr("mysql_stmt_sqlstate"));
+  static ptr2mysql_stmt_sqlstate ptr2_stmt_sqlstate = symbol_safe_cast<ptr2mysql_stmt_sqlstate>(GetProcAddr("mysql_stmt_sqlstate"));
 
   return (*ptr2_stmt_sqlstate)(stmt);
 }
@@ -809,7 +881,7 @@ LibmysqlDynamicProxy::stmt_sqlstate(MYSQL_STMT * stmt)
 int
 LibmysqlDynamicProxy::stmt_store_result(MYSQL_STMT * stmt)
 {
-  ptr2mysql_stmt_store_result ptr2_stmt_store_result = symbol_safe_cast<ptr2mysql_stmt_store_result>(GetProcAddr("mysql_stmt_store_result"));
+  static ptr2mysql_stmt_store_result ptr2_stmt_store_result = symbol_safe_cast<ptr2mysql_stmt_store_result>(GetProcAddr("mysql_stmt_store_result"));
 
   return (*ptr2_stmt_store_result)(stmt);
 }
@@ -820,7 +892,7 @@ LibmysqlDynamicProxy::stmt_store_result(MYSQL_STMT * stmt)
 int
 LibmysqlDynamicProxy::stmt_next_result(MYSQL_STMT * stmt)
 {
-  ptr2mysql_stmt_next_result ptr2_stmt_next_result = symbol_safe_cast<ptr2mysql_stmt_next_result>(GetProcAddr("mysql_stmt_next_result"));
+  static ptr2mysql_stmt_next_result ptr2_stmt_next_result = symbol_safe_cast<ptr2mysql_stmt_next_result>(GetProcAddr("mysql_stmt_next_result"));
   if (ptr2_stmt_next_result != NULL) {
     return (*ptr2_stmt_next_result)(stmt);
   } else {
@@ -834,9 +906,9 @@ LibmysqlDynamicProxy::stmt_next_result(MYSQL_STMT * stmt)
 bool
 LibmysqlDynamicProxy::stmt_free_result(MYSQL_STMT * stmt)
 {
-        ptr2mysql_stmt_free_result ptr2_stmt_free_result = symbol_safe_cast<ptr2mysql_stmt_free_result>(GetProcAddr("mysql_stmt_free_result"));
+  static ptr2mysql_stmt_free_result ptr2_stmt_free_result = symbol_safe_cast<ptr2mysql_stmt_free_result>(GetProcAddr("mysql_stmt_free_result"));
 
-        return (*ptr2_stmt_free_result)(stmt);
+  return (*ptr2_stmt_free_result)(stmt);
 }
 /* }}} */
 
@@ -845,7 +917,7 @@ LibmysqlDynamicProxy::stmt_free_result(MYSQL_STMT * stmt)
 void
 LibmysqlDynamicProxy::thread_end()
 {
-  ptr2mysql_thread_end ptr2_thread_end = symbol_safe_cast<ptr2mysql_thread_end>(GetProcAddr("mysql_thread_end"));
+  static ptr2mysql_thread_end ptr2_thread_end = symbol_safe_cast<ptr2mysql_thread_end>(GetProcAddr("mysql_thread_end"));
 
   (*ptr2_thread_end)();
 }
@@ -856,7 +928,7 @@ LibmysqlDynamicProxy::thread_end()
 void
 LibmysqlDynamicProxy::thread_init()
 {
-  ptr2mysql_thread_init ptr2_thread_init = symbol_safe_cast<ptr2mysql_thread_init>(GetProcAddr("mysql_thread_init"));
+  static ptr2mysql_thread_init ptr2_thread_init = symbol_safe_cast<ptr2mysql_thread_init>(GetProcAddr("mysql_thread_init"));
 
   (*ptr2_thread_init)();
 }
